abacusai.custom_loss_function — AbacusAI documentation

# abacusai.custom_loss_function

## Classes

`CustomLossFunction` | Custom Loss Function

## Module Contents

class abacusai.custom_loss_function.CustomLossFunction(client, notebookId=None, name=None, createdAt=None, lossFunctionName=None, lossFunctionType=None, codeSource={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Custom Loss Function

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - notebookId (str) – The unique identifier of the notebook used to create/edit the loss function.

    - name (str) – Name assigned to the custom loss function.

    - createdAt (str) – When the loss function was created.

    - lossFunctionName (str) – The name of the function defined in the source code.

    - lossFunctionType (str) – The category of problems that this loss would be applicable to, e.g. regression, multi-label classification, etc.

    - codeSource (CodeSource) – Information about the source code of the loss function.

  notebook_id = None
  name = None
  created_at = None
  loss_function_name = None
  loss_function_type = None
  code_source
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict